# Copyright 1999-2005 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit flag-o-matic kde

DESCRIPTION="An open source framework designed to allow KDE applications to index and retrieve files."
HOMEPAGE="http://kat.mandriva.com/"
SRC_URI="mirror://sourceforge/${PN}/${P}.tar.bz2"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~x86 ~amd64 ~alpha ~ppc ~sparc"
IUSE="ext-debian ext-doc ext-dvi ext-gnumeric ext-koffice ext-kpresenter
 ext-kspread ext-kword ext-lyx ext-man ext-openoffice ext-pdf ext-ppt
 ext-ps ext-rpm ext-rtf ext-tex ext-xls xattr"

# Set sqlite to 3.2.1 for now as KDED crashes with sqlite >=3.2.2
# See http://sf.net/tracker/index.php?func=detail&aid=1309476&group_id=131039&atid=719767

RDEPEND="<=dev-db/sqlite-3.2.3
	( || ( ( kde-base/kcontrol kde-base/kicker ) >=kde-base/kdebase-3.3 ) ) 
	ext-debian?	( app-/arch/dpkg )
	ext-doc?	( app-text/antiword )
	ext-dvi?	( dev-tex/dvi2tty )
	ext-gnumeric?	( app-office/gnumeric )
	ext-koffice?	( || ( app-office/koffice app-office/koffice-meta ) )
	ext-kpresenter?	( app-office/kpresenter )
	ext-kspread?	( app-office/kspread )
	ext-kword?	( app-office/kword )
	ext-lyx?	( app-text/lyx2html )
	ext-man?	( app-text/man2html )
	ext-openoffice?	( virtual/ooo )
	ext-pdf?	( app-text/poppler )
	ext-ppt?	( app-text/xlhtml )
	ext-ps?		( app-text/pstotext )
	ext-rpm?	( app-arch/rpm )
	ext-rtf?	( app-text/unrtf )
	ext-tex?	( dev-tex/untex )
	ext-xls?	( app-text/xlhtml )
	xattr?		( sys-apps/attr )"

DEPEND="${RDEPEND}
	>=dev-util/pkgconfig-0.9.0
	!kde-misc/kat-cvs
	!kde-misc/kat-svn"

need-kde 3.3

src_compile() {
	# Filter fvisibility for now due to compile errors
	filter-flags -fvisibility-inlines-hidden -fvisibility=hidden

	# Kat wants autoconf and automake set to newer versions.
	export WANT_AUTOCONF=2.5
	export WANT_AUTOMAKE=1.6

	# Unset Unsermake as it does not compile with unsermake enabled.
	export UNSERMAKE=no

	PREFIX="`kde-config --prefix`"
	kde_src_compile
}

pkg_postinst() {
	if [ ! -d /proc/sys/fs/inotify ] ; then
	    ewarn "Your kernel does not seem to have inotify support enabled."
	    ewarn "In order to enable support for Kat's autoupdate deamon,"
	    ewarn "you need minimum kernel version 2.6.13."
	    ewarn "Enable Inotify file change notification support (INOTIFY)"
	    ewarn "within the kernel under Device Drivers / Character Devices."
	    ewarn "For more information regarding the use of Inotify and Kat:"
	    ewarn "http://kat.mandriva.com/wiki/index.php/Getting_started"
	    ewarn ""
	    epause 10
	fi

	if [ IUSE=xattr ] ; then
	    einfo "You selected support for Extented Attributes within Kat."
	    einfo "You will need to set Extended Attributes on the file"
	    einfo "systems that the autoupdate deamon of Kat indexes."
	    einfo "(Has to be supported by the kernel e.g. EXT2_FS_XATTR,"
	    einfo "EXT3_FS_XATTR or REISERFS_FS_XATTR)"
	    einfo ""
	    einfo "To set extended attributes, add 'user_xattr' to the"
	    einfo "relevant file systems in your /etc/fstab file. For example:"
	    einfo "/dev/hda3   /home  reiserfs	defaults,user_xattr	1 2"
	    epause 10
	fi
}
